@@ -26,6 +26,15 @@ from moosic.utilities import *
 from moosic.client.factory import startServer
 from moosic import VERSION
 
+try:
+    import subprocess
+    def call_find(dir):
+        return subprocess.Popen(['find',dir,'-follow','-type','f','-print'], \
+                stdout=PIPE).stdout.readlines()
+except ImportError:
+    def call_find(dir):
+        return os.popen('find "%s" -follow -type f -print' % dir).readlines()
+
 # Define the True and False constants if they don't already exist.
 try: True
 except NameError: True = 1
@@ -192,7 +201,7 @@ def process_filelist(moosic, arglist, opts):
             arglist = [i + '(?i)' for i in arglist]
         # Get a list of filenames which are eligible for auto-finding.
         dir = sh_escape(opts['music-dir'])
-        files = os.popen('find "%s" -follow -type f -print' % dir).readlines()
+        files = call_find(dir)
         files.sort()
         # Strip off the trailing EOL character.
         files = [item[:-1] for item in files]
@@ -209,7 +218,7 @@ def process_filelist(moosic, arglist, opts):
         arglist = [simplify(a) for a in arglist]
         # Get a list of filenames which are eligible for auto-finding.
         dir = sh_escape(opts['music-dir'])
-        files = os.popen('find "%s" -follow -type f -print' % dir).readlines()
+        files = call_find(dir)
         # Strip off the trailing EOL character.
         files = [item[:-1] for item in files]
         # Simplify the filenames to be searched through, and map each simplified
@@ -249,8 +258,7 @@ def process_filelist(moosic, arglist, opts):
                 # be present on the system. It is almost unthinkable that
                 # you could have a Unix system that didn't have the "find"
                 # command, but you never know.
-                contents = \
-                  os.popen('find "%s" -follow -type f -print' % dir).readlines()
+                contents = call_find(dir)
                 # Strip off the trailing EOL character.
                 contents = [item[:-1] for item in contents]
                 if opts['shuffle-dir']:
