@@ -31,7 +31,7 @@ XML-RPC client implementation for use with Unix sockets.
 It is safe to "import *" from this module.
 """
 
-import xmlrpclib, urllib, httplib, socket, os, os.path, popen2, sys
+import xmlrpclib, urllib, httplib, socket, os, os.path, sys
 import moosic.server.main
 
 # Define the True and False constants if they don't already exist.
@@ -68,9 +68,7 @@ class UnixStreamTransport(xmlrpclib.Transport):
                         self.sock.close()
                     self.sock = None
                     raise
-        class HTTP(httplib.HTTP):
-            _connection_class = HTTPConnection
-        return HTTP(host)
+        return HTTPConnection(host)
 
 
 def LocalMoosicProxy(filename=None):
