@@ -17,7 +17,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import sys, os, os.path, string, time, threading, re
-import socket, SocketServer, signal, atexit
+import socket, signal, atexit
 import cPickle as pickle
 from moosic import VERSION
 from moosic.server.daemonize import daemonize
