@@ -378,6 +378,9 @@ class Log:
 class UnixMoosicRequestHandler(SimpleXMLRPCServer.SimpleXMLRPCRequestHandler):
     """An adaptation of SimpleXMLRPCRequestHandler for use with Unix sockets.
     """
+    # The Nagle algorithm issue doesn't apply to non-TCP sockets.
+    disable_nagle_algorithm = False
+
     def address_string(self):
         """Returns the client address in a format appropriate for logging.
         
@@ -397,7 +400,37 @@ class TcpMoosicRequestHandler(SimpleXMLRPCServer.SimpleXMLRPCRequestHandler):
     pass
 
 
-class UnixMoosicServer(SocketServer.ThreadingMixIn,
+class UnixMoosicServer(SocketServer.UnixStreamServer,
+                       SimpleXMLRPCServer.SimpleXMLRPCServer):
+    """A server that responds to Moosic requests via a Unix (local) socket.
+    """
+    # Portability note: By default, Unix domain sockets are used to implement
+    # interprocess communication between the client and the server. This prevents
+    # this program from working on (most, if not all) non-Unix systems.
+    def __init__(self, addr, logRequests=False):
+        SimpleXMLRPCServer.SimpleXMLRPCServer.__init__(self, addr,
+                requestHandler=UnixMoosicRequestHandler,
+                logRequests=logRequests)
+
+    def handle_error(self, request, client_address):
+        """Handle an error gracefully."""    
+        log_exception(request, client_address)
+
+
+class TcpMoosicServer(SimpleXMLRPCServer.SimpleXMLRPCServer):
+    """A server that responds to Moosic requests via TCP/IP.
+    """
+    def __init__(self, addr, logRequests=False):
+        SimpleXMLRPCServer.SimpleXMLRPCServer.__init__(self, addr,
+                requestHandler=TcpMoosicRequestHandler,
+                logRequests=logRequests)
+
+    def handle_error(self, request, client_address):
+        """Handle an error gracefully."""    
+        log_exception(request, client_address)
+
+
+class ThreadedUnixMoosicServer(SocketServer.ThreadingMixIn,
                        SocketServer.UnixStreamServer,
                        SimpleXMLRPCServer.SimpleXMLRPCServer):
     """A server that responds to Moosic requests via a Unix (local) socket.
@@ -430,25 +463,11 @@ class UnixMoosicServer(SocketServer.ThreadingMixIn,
         t.start()
 
     def handle_error(self, request, client_address):
-        """Handle an error gracefully.
- 
-        This logs a traceback of the error (with "ERROR" priority) and
-        continues.
-        """    
-        exception = sys.exc_info()[1]
-        # Ignore "broken pipe" errors.
-        if isinstance(exception, IOError) and exception[0] == errno.EPIPE:
-            return
-        data.log(Log.ERROR,
-            '-'*40 + '\n' + \
-            'Exception happened during processing of request from ' + \
-            str(client_address) + '\n' + \
-            ''.join(traceback.format_exception(*sys.exc_info())) + \
-            '-'*40
-        )
+        """Handle an error gracefully."""    
+        log_exception(request, client_address)
 
 
-class TcpMoosicServer(SocketServer.ThreadingMixIn,
+class ThreadedTcpMoosicServer(SocketServer.ThreadingMixIn,
                       SimpleXMLRPCServer.SimpleXMLRPCServer):
     """A server that responds to Moosic requests via TCP/IP.
     """
@@ -474,20 +493,23 @@ class TcpMoosicServer(SocketServer.ThreadingMixIn,
         t.start()
 
     def handle_error(self, request, client_address):
-        """Handle an error gracefully.
- 
-        This logs a traceback of the error (with "ERROR" priority) and
-        continues.
-        """    
-        exception = sys.exc_info()[1]
-        # Ignore "broken pipe" errors.
-        if isinstance(exception, IOError) and exception[0] == errno.EPIPE:
-            return
-        data.log(Log.ERROR,
-            '-'*40 + '\n' + \
-            'Exception happened during processing of request from ' + \
-            str(client_address) + '\n' + \
-            ''.join(traceback.format_exception(*sys.exc_info())) + \
-            '-'*40
-        )
+        """Handle an error gracefully."""    
+        log_exception(request, client_address)
 
+def log_exception(request, client_address):
+    """Makes note of an exception in the error log.
+
+    This logs a traceback of the error (with "ERROR" priority) and
+    continues.
+    """    
+    exception = sys.exc_info()[1]
+    # Ignore "broken pipe" errors.
+    if isinstance(exception, IOError) and exception[0] == errno.EPIPE:
+        return
+    data.log(Log.ERROR,
+        '-'*40 + '\n' + \
+        'Exception happened during processing of request from ' + \
+        str(client_address) + '\n' + \
+        ''.join(traceback.format_exception(*sys.exc_info())) + \
+        '-'*40
+    )
